@@ -2,8 +2,8 @@ using System;
 using System.Reflection;
 using System.Runtime.CompilerServices;
 
-[assembly: ApplicationVersion ("2.4.0", "2.4")]
-[assembly: ApplicationBuildInformation ("git-checkout", "linux-gnu", "x86_64", "2012-03-19 20:59:52 CET")]
+[assembly: ApplicationVersion ("2.4.1", "2.4.1")]
+[assembly: ApplicationBuildInformation ("git-checkout", "linux-gnu", "x86_64", "2012-05-31 23:45:33 CEST")]
 
 [assembly: AssemblyVersion ("2.4.0.0")]
 [assembly: AssemblyTitle ("Banshee")]
