@@ -39,6 +39,7 @@ using Banshee.Base;
 using Banshee.Hardware;
 using Banshee.Collection;
 using Banshee.Collection.Database;
+using Folder = Banshee.IO.Directory;
 
 namespace Banshee.Dap.MassStorage
 {
@@ -122,6 +123,13 @@ namespace Banshee.Dap.MassStorage
             playlist_formats = MergeValues ("playlist_formats", config, DefaultPlaylistFormats);
             playlist_path = GetPreferredValue ("playlist_path", config, DefaultPlaylistPath);
             folder_depth = GetPreferredValue ("folder_depth", config, DefaultFolderDepth);
+
+            string preferred_folder_separator = GetPreferredValue ("folder_separator", config, DefaultFolderSeparator);
+            if (preferred_folder_separator == Folder.DosSeparator.ToString () || preferred_folder_separator == "DOS") {
+                folder_separator = Folder.DosSeparator;
+            } else {
+                folder_separator = Folder.UnixSeparator;
+            }
         }
 
         private string[] MergeValues (string key, IDictionary<string, string[]> config, string[] defaultValues)
@@ -200,6 +208,15 @@ namespace Banshee.Dap.MassStorage
             get { return FolderDepth; }
         }
 
+        protected virtual string DefaultFolderSeparator {
+            get { return null; }
+        }
+
+        private char folder_separator;
+        public virtual char FolderSeparator {
+            get { return folder_separator; }
+        }
+
         protected virtual string [] DefaultAudioFolders {
             get { return new string[0]; }
         }
