@@ -120,8 +120,11 @@ namespace Banshee.Mpris
             get { return supported_mimetypes; }
         }
 
+        // We can't use the PlayerEngine.SourceCapabilities property here, because
+        // the OpenUri method only supports "file" and "http".
+        private static string [] supported_uri_schemes = { "file", "http" };
         public string [] SupportedUriSchemes {
-            get { return (string [])ServiceManager.PlayerEngine.ActiveEngine.SourceCapabilities; }
+            get { return supported_uri_schemes; }
         }
 
         public void Raise ()
@@ -324,8 +327,7 @@ namespace Banshee.Mpris
 
         public void OpenUri (string uri)
         {
-            engine_service.Open (new SafeUri (uri));
-            engine_service.Play ();
+            Banshee.Streaming.RadioTrackInfo.OpenPlay (uri);
         }
 
 #endregion
